@@ -19,7 +19,7 @@
 
 # This should be called whenever an archive is made, it will dump some
 # informations (size, md5sum) and will add the archive in .md5 file.
-commit_archive()
+function commit_archive()
 {
 	file_to_create="$1"
     size=$(size_of_path $file_to_create)
@@ -47,13 +47,15 @@ commit_archive()
         error "Unable to purge duplicates of \$file_to_create"
 
     # security fixes if BM_REPOSITORY_SECURE is set to true
-    if [ $BM_REPOSITORY_SECURE = true ]; then
-        chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $file_to_create
-        chmod 660 $file_to_create
+    if [ "$BM_REPOSITORY_SECURE" = "true" ]; then
+        chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $file_to_create || 
+            warning "Unable to change the owner of \"\$file_to_create\"."
+        chmod $BM_ARCHIVE_CHMOD $file_to_create ||
+            warning "Unable to change file permissions of \"\$file_to_create\"."
     fi
 }
 
-commit_archives()
+function commit_archives()
 {    
 	file_to_create="$1"
     if [ "$BM_TARBALL_FILETYPE" = "dar" ]; then
@@ -66,21 +68,20 @@ commit_archives()
     fi
 }
 
-handle_tarball_error()
+function handle_tarball_error()
 {
 	target="$1"
 	logfile="$2"
 
-	warning "Unable to create \$target, check \$logfile"
+	warning "Unable to create \"\$target\", check \$logfile"
 	nb_err=$(($nb_err + 1))
 }
 
-__exec_meta_command()
+function __exec_meta_command()
 {
     command="$1"
     file_to_create="$2"
     compress="$3"
-    words=0
 
     if [ -f $file_to_create ] && [ $force != true ] 
     
@@ -93,37 +94,41 @@ __exec_meta_command()
         case "$compress" in
         "gzip"|"gz")
             if [ -x $gzip ]; then
-                $command 2>$logfile | $gzip -f -q -9 > "$file_to_create.gz"
-                words=$(wc -w $logfile | awk '{print $1}')
-                if [ $words -gt 0 ]; then
+                # we cannot pipe the command to gzip here, or $? will _always_ be 0... 
+                $command 2>$logfile > $file_to_create
+                if [ $? -gt 0 ]; then
                     warning "Unable to exec \$command; check \$logfile"
+                    rm -f $file_to_create
                 else
                     rm -f $logfile
+                    $gzip -f -q -9 "$file_to_create"
+                    file_to_create="$file_to_create.gz"
                 fi
-                file_to_create="$file_to_create.gz"
             else
                 error "Compressor \$compress requires \$gzip."
             fi
         ;;
         "bzip"|"bzip2")
             if [ -x $bzip ]; then
-                $command 2>$logfile | $bzip -f -q -9 > "$file_to_create.bz2"
-                words=$(wc -w $logfile | awk '{print $1}')
-                if [ $words -gt 0 ]; then
+                # we cannot pipe the command to gzip here, or $? will _always_ be 0... 
+                $command 2>$logfile > $file_to_create
+                if [ $? -gt 0 ]; then
                     warning "Unable to exec \$command; check \$logfile"
+                    rm -f $file_to_create
                 else
                     rm -f $logfile
+                    $bzip -f -q -9 "$file_to_create"
+                    file_to_create="$file_to_create.bz2"
                 fi
-                file_to_create="$file_to_create.bz2"
             else
                 error "Compressor \$compress requires \$bzip."
             fi
         ;;
         ""|"uncompressed"|"none")
             $command 1> $file_to_create 2>$logfile
-            words=$(wc -w $logfile | awk '{print $1}')
-            if [ $words -gt 0 ]; then
+            if [ $? -gt 0 ]; then
                 warning "Unable to exec \$command; check \$logfile"
+                rm -f $file_to_create
             else
                 rm -f $logfile
             fi
@@ -141,7 +146,7 @@ __exec_meta_command()
     fi
 }
 
-__create_file_with_meta_command()
+function __create_file_with_meta_command()
 {
     __exec_meta_command "$command" "$file_to_create" "$compress"
     file_to_create="$BM_RET"
@@ -150,21 +155,14 @@ __create_file_with_meta_command()
     fi
 }
 
-__get_flags_tar_blacklist()
-{
-    blacklist=""
-	for pattern in $BM_TARBALL_BLACKLIST
-	do
-		blacklist="$blacklist --exclude=$pattern"
-	done
-    echo "$blacklist"
-}
 
 # Thanks to Michel Grentzinger for his 
 # smart ideas/remarks about that function.
-__get_flags_dar_blacklist()
+function __get_flags_relative_blacklist()
 {
-    target="$1"
+    switch="$1"
+    target="$2"
+
     target=${target%/}
     blacklist=""
 	for pattern in $BM_TARBALL_BLACKLIST
@@ -182,18 +180,31 @@ __get_flags_dar_blacklist()
                 pattern=$(expr substr $pattern 2 $length)
 
                 # ...and blacklisting it
-                blacklist="$blacklist -P $pattern"
+                blacklist="$blacklist ${switch}${pattern}"
            fi
 
         # relative path are blindly appended to the blacklist
         else
-            blacklist="$blacklist -P $pattern"
+            blacklist="$blacklist ${switch}${pattern}"
         fi
     done
-    echo "$blacklist"
+
 }
 
-__get_flags_zip_dump_symlinks()
+function __get_flags_dar_blacklist()
+{
+    target="$1"
+    __get_flags_relative_blacklist "-P" "$target"
+}
+
+function __get_flags_tar_blacklist()
+{
+    target="$1"
+    __get_flags_relative_blacklist "--exclude=" "$target"
+}
+
+
+function __get_flags_zip_dump_symlinks()
 {
     export ZIP="" 
     export ZIPOPT="" 
@@ -204,7 +215,7 @@ __get_flags_zip_dump_symlinks()
     echo "$y"
 }
 
-__get_flags_tar_dump_symlinks()
+function __get_flags_tar_dump_symlinks()
 {
 	h=""
 	if [ "$BM_TARBALL_DUMPSYMLINKS" = "true" ]; then
@@ -213,18 +224,30 @@ __get_flags_tar_dump_symlinks()
     echo "$h"
 }
 
-__get_file_to_create()
+function __get_file_to_create()
 {
     target="$1"
-    dir_name=$(get_dir_name $target $BM_TARBALL_NAMEFORMAT)
-    file_to_create="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$TODAY.$BM_TARBALL_FILETYPE"
+    dir_name=$(get_dir_name "$target" $BM_TARBALL_NAMEFORMAT)
+    file_to_create="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$TODAY${master}.$BM_TARBALL_FILETYPE"
+    
     # dar appends itself the ".dar" extension
     if [ "$BM_TARBALL_FILETYPE" = "dar" ]; then
-        file_to_create="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$TODAY"
+        file_to_create="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$TODAY${master}"
     fi
     echo "$file_to_create"
 }
 
+function __get_file_to_create_remote()
+{
+    target="$1"
+    host="$2"
+    
+    dir_name=$(get_dir_name "$target" $BM_TARBALL_NAMEFORMAT)
+    file_to_create="$BM_REPOSITORY_ROOT/${host}${dir_name}.$TODAY${master}.$BM_TARBALL_FILETYPE"
+    
+    echo "$file_to_create"
+}
+
 function __get_master_day()
 {
     if [ -z "$BM_TARBALLINC_MASTERDATETYPE" ]; then
@@ -262,37 +285,57 @@ function __get_flags_tar_incremental()
 
     # if master day, we have to purge the incremental list if exists
     # so we'll generate a new one (and then, a full backup).
-    if [ "$master_day" = "$BM_TARBALLINC_MASTERDATEVALUE" ] && [ -e $incremental_list ]; then
-        info "Making master backups."
+    if [ "$master_day" -eq "$BM_TARBALLINC_MASTERDATEVALUE" ];  then
+        info "Building master backup for target: \"\$dir_name\"."
         rm -f $incremental_list
     fi
+    if [ -e $incremental_list ]; then
+        master=""
+    fi
     incremental="--listed-incremental $incremental_list"
-
 }
 
+# This will set the appropriate dar options for making incremental backups.
 function __get_flags_dar_incremental()
 {
     dir_name="$1"
     incremental=""
+    
     __get_master_day
     __init_masterdatevalue
+    
     yesterday=$(date +'%Y%m%d' --date '1 days ago')
+    
     yesterday_dar="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday.dar"
-    yesterday_dar_first="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday.1.dar"
-
+    yesterday_dar_first_slice="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday.1.dar"
+    
+    yesterday_dar_master="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday.master.dar"
+    yesterday_dar_master_first_slice="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday.master.1.dar"
+    
     # If we aren't the "full backup" day, we take the previous backup as 
     # a reference for the incremental stuff.
     # We have to find the previous backup for that...
-    if [ "$master_day" != "$BM_TARBALLINC_MASTERDATEVALUE" ]; then
-        if [ -e $yesterday_dar ] || [ -e $yesterday_dar_first ]; then
+    if [ "$master_day" != "$BM_TARBALLINC_MASTERDATEVALUE" ] ; then
+        
+        # Either we have a master backup made yesterday...
+    	if [ -e $yesterday_dar_master ] || 
+           [ -e $yesterday_dar_master_first_slice ] ; then
+            incremental="--ref $BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday.master"
+    
+        # ... Or we have an incremental backup made yesterday
+        elif [ -e $yesterday_dar ] || 
+             [ -e $yesterday_dar_first_slice ] ; then
             incremental="--ref $BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$yesterday"
-        else
-            incremental=""
+        fi
+        
+        # if we use some --ref then, it's not a master but an incremental backup.
+	    if [ -n "$incremental" ] ; then
+    	    master=""
         fi
     fi
 }
 
-__get_flags_dar_maxsize()
+function __get_flags_dar_maxsize()
 {
     if [ -n "$BM_TARBALL_SLICESIZE" ]; then
         maxsize="--alter=SI -s $BM_TARBALL_SLICESIZE"
@@ -300,7 +343,7 @@ __get_flags_dar_maxsize()
     echo "$maxsize"
 }
 
-__get_flags_dar_overwrite()
+function __get_flags_dar_overwrite()
 {
 	if [ $force = true ] ; then
 		overwrite="-w"
@@ -309,79 +352,196 @@ __get_flags_dar_overwrite()
 	echo "$overwrite"
 }
 
-__get_backup_tarball_command()
+# FIXME : incremental is not possible remotely
+# in the current shape...
+function __get_backup_tarball_remote_command()
+{
+    oldgzip="$GZIP"
+    export GZIP="-n"
+    case $BM_TARBALL_FILETYPE in
+        tar) 
+            __get_flags_tar_blacklist "$target"
+            command="$tar $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c "$target""
+        ;;
+        tar.gz)
+            __get_flags_tar_blacklist "$target"
+            command="$tar $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -z "$target""
+        ;;
+        tar.bz2|tar.bz) 
+            __get_flags_tar_blacklist "$target"
+            command="$tar $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -j "$target""
+        ;;
+        *)
+            error "Remote tarball building is not possible with this archive filetype: \"$BM_TARBALL_FILETYPE\"."
+        ;;
+    esac
+    export GZIP="$oldgzip"
+    echo "$command"
+    
+}
+
+function __get_backup_tarball_command()
 {
     case $BM_TARBALL_FILETYPE in
         tar) 
-            command="$tar $incremental $blacklist $dumpsymlinks -p -c    -f "$file_to_create" "$target""
+            __get_flags_tar_blacklist "$target"
+            command="$tar $incremental $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -f"
         ;;
         tar.gz)
-            command="$tar $incremental $blacklist $dumpsymlinks -p -c -z -v -f "$file_to_create" "$target""
+            __get_flags_tar_blacklist "$target"
+            command="$tar $incremental $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -z -f"
         ;;
         tar.bz2|tar.bz) 
-            command="$tar $incremental $blacklist $dumpsymlinks -p -c -j -f "$file_to_create" "$target""
+            if [ ! -x $bzip ]; then
+                error "The archive type \"tar.bz2\" depends on the tool \"\$bzip\"."
+            fi
+            __get_flags_tar_blacklist "$target"
+            command="$tar $incremental $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -j -f"
+        ;;
+        tar.lz)
+            if [ ! -x $lzma ]; then
+                error "The archive type \"tar.lz\" depends on the tool \"\$lzma\"."
+            fi
+            __get_flags_tar_blacklist "$target"
+            command="$tar $incremental $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -f - $target | $lzma -si e"
         ;;
         zip) 
-            command="$zip $dumpsymlinks -r "$file_to_create" "$target""
+            if [ ! -x $zip ]; then
+                error "The archive type \"zip\" depends on the tool \"\$zip\"."
+            fi
+            command="$zip $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -r"
         ;;
         dar)
-            blacklist=""
-            blacklist="$(__get_flags_dar_blacklist "$target")"
-            command="$dar $incremental $blacklist $maxsize $overwrite -z9 -Q -c "$file_to_create" -R "$target""
+            if [ ! -x $dar ]; then
+                error "The archive type \"dar\" depends on the tool \"\$dar\"."
+            fi
+            __get_flags_dar_blacklist "$target"
+            command="$dar $incremental $blacklist $maxsize $overwrite $BM_TARBALL_EXTRA_OPTIONS -z9 -Q -c $file_to_create -R"
         ;;
         *)
+            error "The archive type \"\$BM_TARBALL_FILETYPE\" is not supported."
             return 1
         ;;
     esac
     echo "$command"
 }
 
-__make_tarball_archives()
+function build_clear_archive
 {
-    nb_err=0
-	for target in $BM_TARBALL_DIRECTORIES
-	do
-        # first be sure the target exists
-		if [ ! -e $target ] || [ ! -r $target ]; then
-			warning "Target \$target does not exist, skipping."
-			nb_err=$(($nb_err + 1))
-			continue
-		fi
-		
-        dir_name=$(get_dir_name "$target" $BM_TARBALL_NAMEFORMAT)
-        file_to_create=$(__get_file_to_create "$target")
-    
-        # handling of incremental options
-        incremental=""
-        if [ $method = tarball-incremental ]
-        then
-            case $BM_TARBALL_FILETYPE in
-                dar)
-                    __get_flags_dar_incremental $dir_name
-                ;;
-                
-                *)
-                    if [ "$BM_TARBALL_FILETYPE" != "zip" ]; then
-                        __get_flags_tar_incremental "$dir_name"
-                    fi
-                ;;
-            esac
-        fi
-        command=$(__get_backup_tarball_command) || 
-            error "The filetype \$BM_TARBALL_FILETYPE is not supported."
+    logfile=$(mktemp /tmp/bm-tarball.log.XXXXXX)
 
+    # A couple of archive types have a special command line
+    case "$BM_TARBALL_FILETYPE" in 
 
-        # dar is not like tar, we have to manually check for existing .1.dar files
-        if [ $BM_TARBALL_FILETYPE = dar ]; then
-            file_to_check="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$TODAY.1.dar"
-        else
-            file_to_check="$file_to_create"
-        fi
+        # lzma archives should be piped manually
+        "tar.lz")
+            $tar $incremental $blacklist $dumpsymlinks $BM_TARBALL_EXTRA_OPTIONS -p -c -f - $target 2>>$logfile | $lzma -si e $file_to_create 2>>$logfile
+            if [ $? -gt 0 ]; then
+                handle_tarball_error "$file_to_create" "$logfile"
+            else
+                rm -f $logfile
+                commit_archives "$file_to_create"
+            fi
+        ;;
         
+        # dar has a special commandline, that cannot fit the common tar way
+        "dar")
+            if ! `$command "$target"> $logfile 2>&1`; then
+                handle_tarball_error "$file_to_create" "$logfile"
+            else
+                rm -f $logfile
+                commit_archives "$file_to_create"
+            fi
+        ;;
+
+        # the common commandline
+        *)
+            if ! `$command $file_to_create "$target"> $logfile 2>&1`; then
+                handle_tarball_error "$file_to_create" "$logfile"
+            else
+                rm -f $logfile
+                commit_archives "$file_to_create"
+            fi
+        ;;
+    esac
+}
+
+function build_encrypted_archive
+{
+    logfile=$(mktemp /tmp/bm-tarball.log.XXXXXX)
+
+    if [ -z "$BM_ENCRYPTION_RECIPIENT" ]; then
+        error "The configuration variable \"BM_ENCRYPTION_RECIPIENT\" must be defined."
+    fi
+
+    if [ "$BM_TARBALL_FILETYPE" = "tar.lz" ] || 
+       [ "$BM_TARBALL_FILETYPE" = "zip" ] ||
+       [ "$BM_TARBALL_FILETYPE" = "dar" ]; then
+        error "The encryption is not yet possible with \"\$BM_TARBALL_FILETYPE\" archives."
+    fi
+
+    file_to_create="$file_to_create.gpg"
+    if ! `$command - "$target" 2>>$logfile | $gpg -r "$BM_ENCRYPTION_RECIPIENT" -e > $file_to_create 2>> $logfile`; then
+        handle_tarball_error "$file_to_create" "$logfile"
+    else
+        rm -f $logfile
+        commit_archives "$file_to_create"
+    fi
+}
+
+function __build_local_archive()
+{
+    target="$1"
+    dir_name="$2"
+    
+    file_to_create=$(__get_file_to_create "$target")
+    command="$(__get_backup_tarball_command)" || 
+        error "The archive type \"\$BM_TARBALL_FILETYPE\" is not supported."
+
+    # dar is not like tar, we have to manually check for existing .1.dar files
+    if [ $BM_TARBALL_FILETYPE = dar ]; then
+        file_to_check="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$dir_name.$TODAY.1.dar"
+    else
+        file_to_check="$file_to_create"
+    fi
+
+    # let's exec the command
+    if [ ! -e $file_to_check ] || [ $force = true ]; then
+        if [ "$BM_ENCRYPTION_METHOD" = "gpg" ]; then
+            if [ ! -x $gpg ]; then
+                error "The program \"\$gpg\" is needed."
+            fi
+            build_encrypted_archive
+        else
+            build_clear_archive
+        fi
+    else
+        warning "File \$file_to_check already exists, skipping."
+        continue
+    fi
+}
+
+function __build_remote_archive()
+{
+    target="$1"
+    dir_name="$2"
+    
+    for host in $BM_UPLOAD_SSH_HOSTS
+    do
+        logfile=$(mktemp /tmp/bm-tarball.log.XXXXXX)
+        file_to_create=$(__get_file_to_create_remote "$target" "$host")
+        
+        command=$(__get_backup_tarball_remote_command) || 
+            error "The archive type \"\$BM_TARBALL_FILETYPE\" is not supported."
+        
+        remote_command="ssh -p ${BM_UPLOAD_SSH_PORT} -i ${BM_UPLOAD_SSH_KEY} -o BatchMode=yes ${BM_UPLOAD_SSH_USER}@${host} $command"
+        file_to_check="$file_to_create"
+
         if [ ! -e $file_to_check ] || [ $force = true ]; then
+             
             logfile=$(mktemp /tmp/bm-tarball.log.XXXXXX)
-#            __debug "$command"
-            if ! $command > $logfile 2>&1 ; then
+            $remote_command > "$file_to_create" 2>$logfile
+            if [ $? -gt 0 ]; then
                 handle_tarball_error "$file_to_create" "$logfile"
             else
                 rm -f $logfile
@@ -394,25 +554,94 @@ __make_tarball_archives()
     done
 }
 
+function __make_remote_tarball_token
+{
+    t="$1"
+    dir_name=$(get_dir_name "$t" $BM_TARBALL_NAMEFORMAT)
+    master=".master"
+    __build_remote_archive "$t" "$dir_name"
+}
+
+function __make_local_tarball_token
+{
+    t="$1"
+
+    if [ ! -e "$t" ] || [ ! -r "$t" ]; then
+        # first be sure the target exists
+        warning "Target \"\$t\" does not exist, skipping."
+        nb_err=$(($nb_err + 1))
+    
+    else
+        # we assume we'll build a master backup (full archive).
+        # If we make incremental backup, the $master keyword 
+        # will be reset.
+        dir_name=$(get_dir_name "$t" $BM_TARBALL_NAMEFORMAT)
+        master=".master"
+    
+        # handling of incremental options
+        incremental=""
+
+        if [ $method = tarball-incremental ]
+        then
+            case "$BM_TARBALL_FILETYPE" in
+            "dar")
+                __get_flags_dar_incremental "$dir_name"
+            ;;
+            "tar"|"tar.gz"|"tar.bz2")
+                __get_flags_tar_incremental "$dir_name"
+            ;;
+            esac
+        fi
+        __build_local_archive "$t" "$dir_name"       
+    fi
+}
+
+function __make_remote_tarball_archives()
+{
+    nb_err=0
+    for target in "${BM_TARBALL_TARGETS[@]}"
+    do
+        if [ -z "$target" ]; then
+            continue
+        fi
+        __make_remote_tarball_token "$target"
+    done
+}
+
+function __make_local_tarball_archives()
+{
+    nb_err=0
+    for target in "${BM_TARBALL_TARGETS[@]}"
+    do
+        if [ -z "$target" ]; then
+            continue
+        fi
+        target_expanded="$(eval 'echo $target')"
+        
+        # if the target exists, handle it as a single token
+        if [ -r "$target_expanded" ]; then
+            __make_local_tarball_token "$target_expanded"
+
+        # else try to expand the target in several tokens
+        else
+            for t in $target_expanded
+            do
+                __make_local_tarball_token "$t"
+            done
+        fi            
+    done
+}
+
 # This manages both "tarball" and "tarball-incremental" methods.
 # configuration keys: BM_TARBALL_* and BM_TARBALLINC_*
-backup_method_tarball()
+function backup_method_tarball()
 {
     method="$1"
 	info "Using method \"\$method\"."
 	
     # build the command line
     case $BM_TARBALL_FILETYPE in 
-    tar.gz)
-        blacklist="$(__get_flags_tar_blacklist)"
-        dumpsymlinks="$(__get_flags_tar_dump_symlinks)"
-    ;;
-    tar)
-        blacklist="$(__get_flags_tar_blacklist)"
-        dumpsymlinks="$(__get_flags_tar_dump_symlinks)"
-    ;;
-    tar.bz2|tar.bz)
-        blacklist="$(__get_flags_tar_blacklist)"
+    tar|tar.bz2|tar.gz)
         dumpsymlinks="$(__get_flags_tar_dump_symlinks)"
     ;;
     zip)
@@ -424,15 +653,21 @@ backup_method_tarball()
     ;;
     esac
 
-    __make_tarball_archives
+    if [ "$BM_TARBALL_OVER_SSH" != "true" ]; then
+        __make_local_tarball_archives
+    else
+        __make_remote_tarball_archives
+    fi
 	
     # Handle errors
-	if [ $nb_err -gt 0 ]; then
-		error "During the tarballs generation, \$nb_err error(s) occurred."
-	fi
+	if [ $nb_err -eq 1 ]; then
+		error "1 error occurred during the tarball generation."
+	elif [ $nb_err -gt 1 ]; then
+        error "\$nb_err errors occurred during the tarball generation."
+    fi
 }
 
-backup_method_mysql()
+function backup_method_mysql()
 {
     method="$1"
 	info "Using method \"\$method\"."
@@ -461,7 +696,7 @@ backup_method_mysql()
     done   
 }
 
-backup_method_svn()
+function backup_method_svn()
 {
     method="$1"
     info "Using method \"\$method\"."
@@ -476,14 +711,14 @@ backup_method_svn()
         else
             archive_name=$(get_dir_name $repository "long")
             file_to_create="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX$archive_name.$TODAY.svn"
-            command="$svnadmin dump $repository"
+            command="$svnadmin -q dump $repository"
             compress="$BM_SVN_COMPRESSWITH"
             __create_file_with_meta_command
         fi
     done
 }
 
-backup_method_pipe()
+function backup_method_pipe()
 {
     method="$1"
     info "Using method \"\$method\"."
