@@ -87,7 +87,7 @@ replace_deprecated_booleans()
             key=$(echo "$line" | awk -F '=' '{print $1}')
             value=$(echo "$line" | awk -F '=' '{print $2}')
           
-            if [ $(expr match $key BM_) -gt 0 ]; then
+            if [ $(expr match "$key" BM_) -gt 0 ]; then
                 if [ "$value" = "yes" ]; then
                     warning "Deprecated boolean, \$key is set to \"yes\", setting \"true\" instead."
 	                nb_warnings=$(($nb_warnings + 1))
@@ -107,9 +107,14 @@ replace_deprecated_booleans()
 # the best possible, with default values and so on...
 #############################################################
 
+# First of all replace yes/no booleans with true/false ones.
+replace_deprecated_booleans
+
 confkey_handle_deprecated "BM_ARCHIVES_REPOSITORY" "BM_REPOSITORY_ROOT"
 confkey_require "BM_REPOSITORY_ROOT" "/var/archives" 
 
+# let's drop the trailing slash, if any.
+export BM_REPOSITORY_ROOT="${BM_REPOSITORY_ROOT%/}"
 
 confkey_require "BM_REPOSITORY_SECURE" "true" 
 if [ "$BM_REPOSITORY_SECURE" = "true" ]; then
@@ -117,8 +122,12 @@ if [ "$BM_REPOSITORY_SECURE" = "true" ]; then
 	confkey_require "BM_REPOSITORY_USER" "root"
 	confkey_handle_deprecated "BM_GROUP" "BM_REPOSITORY_GROUP"
 	confkey_require "BM_REPOSITORY_GROUP" "root"
+    confkey_require "BM_REPOSITORY_CHMOD" "770"
+    confkey_require "BM_ARCHIVE_CHMOD" "660"
 fi
 
+confkey_require "BM_REPOSITORY_RECURSIVEPURGE" "false" 
+
 confkey_handle_deprecated "BM_MAX_TIME_TO_LIVE" "BM_ARCHIVE_TTL"
 confkey_require "BM_ARCHIVE_TTL" "5"
 
@@ -136,19 +145,45 @@ if [ "$BM_ARCHIVE_METHOD" = "tarball-incremental" ] &&
         confkey_require "BM_TARBALLINC_MASTERDATETYPE" "weekly"
 fi
 
-if [ "$BM_ARCHIVE_METHOD" = "tarball" ]; then
-
-	confkey_handle_deprecated "BM_FILETYPE" "BM_TARBALL_FILETYPE"
+if [ "$BM_ARCHIVE_METHOD" = "tarball" ] || 
+   [ "$BM_ARCHIVE_METHOD" = "tarball-incremental" ] ; then
 	confkey_require "BM_TARBALL_FILETYPE" "tar.gz"
-
-	confkey_handle_deprecated "BM_NAME_FORMAT" "BM_TARBALL_NAMEFORMAT"
 	confkey_require "BM_TARBALL_NAMEFORMAT" "long"
-
-	confkey_handle_deprecated "BM_DUMP_SYMLINKS" "BM_TARBALL_DUMPSYMLINKS"
 	confkey_require "BM_TARBALL_DUMPSYMLINKS" "false"
+fi
 
-	confkey_handle_deprecated "BM_DIRECTORIES" "BM_TARBALL_DIRECTORIES"
-	confkey_handle_deprecated "BM_DIRECTORIES_BLACKLIST" "BM_TARBALL_BLACKLIST"
+confkey_handle_deprecated "BM_FILETYPE" "BM_TARBALL_FILETYPE"
+confkey_handle_deprecated "BM_NAME_FORMAT" "BM_TARBALL_NAMEFORMAT"
+confkey_handle_deprecated "BM_DIRECTORIES_BLACKLIST" "BM_TARBALL_BLACKLIST"
+confkey_handle_deprecated "BM_DUMP_SYMLINKS" "BM_TARBALL_DUMPSYMLINKS"
+
+# The TARBALL_OVER_SSH thing
+if [ "$BM_TARBALL_OVER_SSH" = "true" ]; then
+    if [ -z "$BM_UPLOAD_SSH_HOSTS" ]; then
+        confkey_error "BM_UPLOAD_SSH_HOSTS" "BM_TARBALL_OVER_SSH"
+    fi
+    if [ -z "$BM_UPLOAD_SSH_KEY" ]; then
+        confkey_error "BM_UPLOAD_SSH_KEY" "BM_TARBALL_OVER_SSH"
+    fi
+    if [ -z "$BM_UPLOAD_SSH_USER" ]; then
+        confkey_error "BM_UPLOAD_SSH_USER" "BM_TARBALL_OVER_SSH"
+    fi
+    confkey_require "BM_UPLOAD_SSH_PORT" "22"
+fi
+
+# Converting anything in BM_TARBALL_DIRECTORIES in the array BM_TARBALL_TARGETS[].
+# see bug #86 for details.
+if [ -n "$BM_DIRECTORIES" ]; then
+    BM_TARBALL_DIRECTORIES="$BM_DIRECTORIES"
+fi
+if [ -n "$BM_TARBALL_DIRECTORIES" ]; then
+    declare -a BM_TARBALL_TARGETS
+    index=0
+    for target in $BM_TARBALL_DIRECTORIES
+    do
+        BM_TARBALL_TARGETS[$index]="$target"
+        index=$(($index + 1))
+    done
 fi
 
 if [ "$BM_UPLOAD_METHOD" = "rsync" ]; then
@@ -157,6 +192,10 @@ if [ "$BM_UPLOAD_METHOD" = "rsync" ]; then
 	confkey_handle_deprecated "BM_UPLOAD_USER" "BM_UPLOAD_SSH_USER"
 fi
 
+if [ "$BM_UPLOAD_METHOD" = "ssh" ]; then
+    confkey_require "BM_UPLOAD_SSH_PORT" "22"
+fi
+
 if [ "$BM_ARCHIVE_METHOD" = "mysql" ]; then
 	confkey_require "BM_MYSQL_ADMINLOGIN" "root"
 	confkey_require "BM_MYSQL_ADMINPASS" ""
@@ -199,7 +238,6 @@ if [ -n "$BM_UPLOAD_MODE" ]; then
     confkey_handle_deprecated "BM_UPLOAD_DIR" "BM_UPLOAD_DESTINATION"
 fi        
 
-replace_deprecated_booleans
 
 confkey_require "BM_LOGGER" "true"
 if [ "$BM_LOGGER" = "true" ]; then 
