@@ -50,19 +50,60 @@ bm_upload_ssh()
     # the flags for the SSH method
     k_switch=""
     if [ ! -z "$BM_UPLOAD_SSH_KEY" ]; then
-        k_switch="-k=\"$BM_UPLOAD_SSH_KEY\""
+        k_switch="-k=$BM_UPLOAD_SSH_KEY"
+    fi
+
+    ssh_purge_switch=""
+    if [ "$BM_UPLOAD_SSH_PURGE" = "true" ]; then
+        ssh_purge_switch="--ssh-purge"
     fi
 
     # Call to backup-manager-upload
-    su $BM_UPLOAD_SSH_USER -s /bin/sh -c \
-    "$bmu $v_switch \
-          $k_switch \
-          -m=\"scp\" \
-          -h=\"$bm_upload_hosts\" \
-          -u=\"$BM_UPLOAD_SSH_USER\" \
-          -d=\"$BM_UPLOAD_SSH_DESTINATION\" \
-          -r=\"$BM_REPOSITORY_ROOT\" today" || 
-    error "Unable to call backup-manager-upload."
+    logfile="$(mktemp /tmp/bmu-log.XXXXXX)"
+    $bmu $v_switch $k_switch $ssh_purge_switch -m="scp" \
+          -h="$bm_upload_hosts" \
+          -u="$BM_UPLOAD_SSH_USER" \
+          -d="$BM_UPLOAD_SSH_DESTINATION" \
+          -r="$BM_REPOSITORY_ROOT" today 2>$logfile || 
+    error "Error reported by backup-manager-upload for method \"scp\", check \"\$logfile\"."
+    rm -f $logfile
+}
+
+
+# Manages encrypted SSH uploads
+bm_upload_ssh_gpg()
+{
+    info "Using the upload method \"ssh-gpg\"."
+    
+    bm_upload_hosts="$BM_UPLOAD_HOSTS $BM_UPLOAD_SSH_HOSTS"
+    bm_upload_init "$bm_upload_hosts"
+
+    if [ -z "$BM_UPLOAD_SSH_DESTINATION" ]; then
+        BM_UPLOAD_SSH_DESTINATION="$BM_UPLOAD_DESTINATION"
+    fi        
+    if [ -z "$BM_UPLOAD_SSH_DESTINATION" ]; then
+        error "No valid destination found, SSH upload not possible."
+    fi        
+    if [ -z "$BM_UPLOAD_SSHGPG_RECIPIENT" ]; then
+        error "No gpg recipient given. Argument is mandatory if upload method ssh-gpg is used."
+    fi
+
+    # the flags for the SSH method
+    k_switch=""
+    if [ ! -z "$BM_UPLOAD_SSH_KEY" ]; then
+        k_switch="-k=$BM_UPLOAD_SSH_KEY"
+    fi
+
+    # Call to backup-manager-upload
+    logfile="$(mktemp /tmp/bmu-log.XXXXXX)"
+    $bmu $v_switch $k_switch -m="ssh-gpg" \
+         -h="$bm_upload_hosts" \
+         -u="$BM_UPLOAD_SSH_USER" \
+         -d="$BM_UPLOAD_SSH_DESTINATION" \
+         -r="$BM_REPOSITORY_ROOT" \
+         --gpg-recipient="$BM_UPLOAD_SSHGPG_RECIPIENT" today 2>$logfile|| 
+    error "Error reported by backup-manager-upload for method \"ssh-gpg\", check \"\$logfile\"."
+    rm -f $logfile
 }
 
 # Manages FTP uploads
@@ -87,43 +128,77 @@ bm_upload_ftp()
             ftp_purge_switch="--ftp-purge"
     fi
  
+    logfile="$(mktemp /tmp/bmu-log.XXXXXX)"
     $bmu $v_switch $ftp_purge_switch \
         -m="ftp" \
         -h="$bm_upload_hosts" \
         -u="$BM_UPLOAD_FTP_USER" \
         -p="$BM_UPLOAD_FTP_PASSWORD" \
         -d="$BM_UPLOAD_FTP_DESTINATION" \
-        -r="$BM_REPOSITORY_ROOT" today || 
-    error "Unable to call backup-manager-upload."
+        -r="$BM_REPOSITORY_ROOT" today 2>$logfile|| 
+    error "Error reported by backup-manager-upload for method \"ftp\", check \"\$logfile\"."
+    rm -f $logfile
 
 }
 
-# this is done for behaving the right way depending on who is calling us
-# root should use su $BM_UPLOAD_SSH_USER -c ... and a regular user can just pray for being
-# $BM_UPLOAD_SSH_USER...
+# Manages S3 uploads
+bm_upload_s3()
+{
+    info "Using the upload method \"S3\"."
+
+    bm_upload_hosts="s3.amazon.com"
+    bm_upload_init "$bm_upload_hosts" 
+    
+    if [ -z "$BM_UPLOAD_S3_DESTINATION" ]; then
+	    BM_UPLOAD_S3_DESTINATION="$BM_UPLOAD_DESTINATION"
+    fi        
+
+    # flags for the S3 method
+    s3_purge_switch=""
+    if [ "$BM_UPLOAD_S3_PURGE" = "true" ]; then
+        s3_purge_switch="--s3-purge"
+    fi
+ 
+    logfile="$(mktemp /tmp/bmu-log.XXXXXX)"
+    $bmu $v_switch $s3_purge_switch \
+        -m="s3" \
+        -h="$bm_upload_hosts" \
+        -u="$BM_UPLOAD_S3_ACCESS_KEY" \
+        -p="$BM_UPLOAD_S3_SECRET_KEY" \
+        -b="$BM_UPLOAD_S3_DESTINATION" \
+        -r="$BM_REPOSITORY_ROOT" today 2>$logfile || 
+    error "Error reported by backup-manager-upload for method \"s3\", check \"\$logfile\"."
+    rm -f $logfile
+}
+
 _exec_rsync_command()
 {
     info "Uploading \$directory to \${host}:\${BM_UPLOAD_RSYNC_DESTINATION}"
     logfile=$(mktemp /tmp/bm-rsync.XXXXXX)
-    if [ "$UID" != 0 ]; then
-        if ! ${rsync} ${rsync_options} \
-             -e "ssh -o BatchMode=yes -o ServerAliveInterval=60 -i ${BM_UPLOAD_SSH_KEY}" ${directory} \
-                 ${BM_UPLOAD_SSH_USER}@${host}:$BM_UPLOAD_RSYNC_DESTINATION/${RSYNC_SUBDIR}/\
-                 >/dev/null 2>$logfile; then
-            error "Upload of \$directory with rsync failed; check \$logfile."
-        else
-            rm -f $logfile
-        fi
-    else
-        if ! su $BM_UPLOAD_SSH_USER -c "${rsync} ${rsync_options} \
-             -e \"ssh -o BatchMode=yes -o ServerAliveInterval=60 -i ${BM_UPLOAD_SSH_KEY}\" ${directory} \
-                 ${BM_UPLOAD_SSH_USER}@${host}:$BM_UPLOAD_RSYNC_DESTINATION/${RSYNC_SUBDIR}/" \
-                 >/dev/null 2>$logfile; then
-            error "Upload of \$directory with rsync failed; check \$logfile."
-        else
-            rm -f $logfile
+
+    # default options for local rsync
+    ssh_option=""
+    destination_option="$BM_UPLOAD_RSYNC_DESTINATION/${RSYNC_SUBDIR%/}"
+    
+    # remote hosts use SSH
+    if [ "$host" != "localhost" ]; then
+        if [ -z "$BM_UPLOAD_SSH_USER" ] || 
+           [ -z "$BM_UPLOAD_SSH_KEY" ]; then 
+            error "Need a key to use rsync (set BM_UPLOAD_SSH_USER, BM_UPLOAD_SSH_KEY)."
         fi
+        ssh_option="ssh -l ${BM_UPLOAD_SSH_USER} -o BatchMode=yes -o ServerAliveInterval=60 -i ${BM_UPLOAD_SSH_KEY}"
+        destination_option="${BM_UPLOAD_SSH_USER}@${host}:${destination_option}"
     fi
+    
+    # Due to a very weird behaviour in the rsync's argument-processing phase;
+    # it's safer to use RSYNC_RSH to pass ssh options than using the -e '' flag.
+    command="${rsync_options} ${directory} ${destination_option}"
+    if ! RSYNC_RSH="$ssh_option" \
+         $rsync $command >$logfile 2>&1; then
+        error "Upload of \$directory with rsync failed; check \$logfile."
+    else
+        rm -f $logfile
+    fi        
 }
 
 # Manages RSYNC uploads
@@ -132,13 +207,16 @@ bm_upload_rsync_common()
     bm_upload_hosts="$BM_UPLOAD_HOSTS $BM_UPLOAD_RSYNC_HOSTS"
     bm_upload_init "$bm_upload_hosts"
 
+    if [ -z "$bm_upload_hosts" ]; then
+        bm_upload_hosts="localhost"
+    fi
     if [ -z "$BM_UPLOAD_RSYNC_DESTINATION" ]; then
         BM_UPLOAD_RSYNC_DESTINATION="$BM_UPLOAD_DESTINATION"
     fi        
     if [ -z "$BM_UPLOAD_RSYNC_DESTINATION" ]; then
         error "No valid destination found, RSYNC upload not possible."
     fi
-
+    
     rsync_options="-va"
     if [ ! -z $BM_UPLOAD_RSYNC_DUMPSYMLINKS ]; then
         if [ "$BM_UPLOAD_RSYNC_DUMPSYMLINKS" = "true" ]; then
@@ -149,21 +227,15 @@ bm_upload_rsync_common()
     for directory in $BM_UPLOAD_RSYNC_DIRECTORIES
     do
         if [ -n "$bm_upload_hosts" ]; then
-            if [ -n "$BM_UPLOAD_SSH_KEY" ] && 
-               [ -n "$BM_UPLOAD_SSH_USER" ]; then
-                servers=`echo $bm_upload_hosts| sed 's/ /,/g'`
-
-                for host in $servers
-                do
-                    _exec_rsync_command
-                done
-            else
-                error "Need a key to use rsync (set BM_UPLOAD_SSH_USER, BM_UPLOAD_SSH_KEY)."
-            fi
+            servers=`echo $bm_upload_hosts| sed 's/ /,/g'`
+            for host in $servers
+            do
+                _exec_rsync_command
+            done
         else
             warning "No hosts given to the rsync method, set BM_UPLOAD_RSYNC_HOSTS."
         fi
-      done
+    done
 }
 
 bm_upload_rsync()
