@@ -1,15 +1,22 @@
-#!/bin/sh
+#!/bin/bash
 
 set -e
+# set -x
 
-test_failure()
+function count()
+{
+    total=$(($total + 1))
+}
+
+function test_failure()
 {
     file="$1"
     nb_failure=$(($nb_failure + 1))
     echo "failed"
+
 }
 
-test_success()
+function test_success()
 {
     file="$1"
     nb_success=$(($nb_success + 1))
@@ -24,19 +31,26 @@ if [ -f ./backup-manager.conf ]; then
     init_default_vars
 fi
 
-
+total=0
+nb_failure=0
 # Now process the tests
 for file in t[0-9][0-9]*.sh
 do
-        echo -n "Running test $file:"
-        if /bin/bash $file; then
+        count
+        echo -n "[t $total] Running test $file:"
+        
+        if /bin/bash $file 2>/dev/null; then
             test_success $file
         else
             test_failure $file
         fi              
 done
 
-echo "---------------------------------------------------"
-echo "Failed tests:    $nb_failure"
-echo "Sucessful tests: $nb_success"
+echo "------------------------------------------------------------------------------"
+pct_success=$(($nb_success * 100 / $total))
+echo "Success score: $pct_success% ($nb_success/$total)"
+if [ "$nb_failure" -gt 0 ]; then
+    echo "Failed tests: $nb_failure"
+fi
+
 
