@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 set -e
 
@@ -16,6 +16,8 @@ source confs/tarball.conf
 export BM_ARCHIVE_ROOT="repository"
 export BM_ARCHIVE_METHOD="tarball"
 export BM_TARBALL_DIRECTORIES="$PWD"
+export BM_TARBALL_FILETYPE="tar.gz"
+source $locallib/sanitize.sh
 
 # The test actions
 
@@ -25,11 +27,13 @@ fi
 
 bm_init_env
 bm_init_today
+
 create_directories
 make_archives
 
 name=$(get_dir_name $PWD long)
-if [ -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.tar.gz" ]; then
+if [ -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.master.tar.gz" ]; then
+    rm -rf $BM_ARCHIVE_ROOT
     exit 0
 else
     exit 1
