@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 set -e
 
@@ -14,6 +14,7 @@ source confs/base.conf
 export BM_ARCHIVE_METHOD="none"
 export BM_UPLOAD_METHOD="none"
 export BM_BURNING_METHOD="none"
+source $locallib/sanitize.sh
 
 # The test actions
 bm_init_env
@@ -23,4 +24,6 @@ make_archives
 upload_files
 burn_files
 
+rm -rf repository
+
 exit 0
