@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 set -e
 
@@ -17,6 +17,7 @@ export BM_TARBALL_FILETYPE="tar.gz"
 export BM_TARBALL_DUMPSYMLINKS="no"
 export BM_TARBALL_DIRECTORIES="$PWD/var/www/"
 export BM_TARBALL_BLACKLIST="$PWD/var/www/xim $PWD/var/www/Upload"
+source $locallib/sanitize.sh
 
 # clean
 if [ -e $PWD/var ]; then
@@ -45,7 +46,7 @@ make_archives
 
 # test of success/failure
 name=$(get_dir_name "$PWD/var/www" "long")
-archive="$BM_ARCHIVE_PREFIX$name.$TODAY.tar.gz"
+archive="$BM_ARCHIVE_PREFIX$name.$TODAY.master.tar.gz"
 
 if [ -e $BM_REPOSITORY_ROOT/$archive ]
 then
@@ -59,13 +60,19 @@ then
                 cat $tempfile
            fi
            rm -f $tempfile
+           rm -rf $PWD/var
+           rm -rf $PWD/repository
            exit 1
         else
             rm -f $tempfile
+           rm -rf $PWD/var
+           rm -rf $PWD/repository
             exit 0
         fi                
 else
     warning "$archive doesn't exists"
+    rm -rf $PWD/var
+    rm -rf $PWD/repository
     exit 1
 fi    
 
