@@ -1,9 +1,10 @@
-#!/bin/sh
+#!/bin/bash
 
 set -e
 
 # Each test script should include testlib.sh
 source testlib.sh
+
 # When the test is ready, set this to false for nice outputs.
 # if you want to see what happens, use those flags
 # verbose="true"
@@ -20,8 +21,14 @@ export BM_TARBALL_FILETYPE="dar"
 export BM_TARBALLINC_MASTERDATETYPE="weekly"
 export BM_TARBALLINC_MASTERDATEVALUE="1"
 
-# The test actions
+source $locallib/sanitize.sh
 
+if [ ! -x $dar ]; then
+    info "cannot run test, need $dar"
+    exit 1
+fi
+
+# The test actions
 if [ -e $BM_ARCHIVE_ROOT ]; then
     rm -f $BM_ARCHIVE_ROOT/*
 fi    
@@ -32,8 +39,10 @@ create_directories
 make_archives
 
 name=$(get_dir_name $PWD long)
-if [ -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.1.dar" ]; then
+if [ -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.master.1.dar" ]; then
+    rm -rf $BM_ARCHIVE_ROOT
     exit 0
 else
+    rm -rf $BM_ARCHIVE_ROOT
     exit 1
 fi        
