@@ -3,8 +3,8 @@
 set -e
 
 source testlib.sh
-#verbose="true"
-#warnings="true"
+# verbose="true"
+# warnings="true"
 
 source confs/base.conf
 
@@ -12,6 +12,7 @@ source confs/base.conf
 # http://bugzilla.backup-manager.org/cgi-bin/attachment.cgi?id=1&action=view
 export BM_REPOSITORY_ROOT="$PWD/repository"
 export BM_ARCHIVE_METHOD="pipe"
+source $locallib/sanitize.sh
 bm_init_env
 bm_init_today
 
@@ -33,6 +34,11 @@ BM_PIPE_FILETYPE[2]="txt"
 BM_PIPE_COMPRESS[2]=""
 files[2]="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX-ls-root.$TODAY.txt"
 
+# BM_PIPE_COMMAND[3]="/usr/bin/tototot"
+# BM_PIPE_NAME[3]="failure"
+# BM_PIPE_FILETYPE[3]="txt"
+# BM_PIPE_COMPRESS[3]=""
+
 # clean
 if [ -e $PWD/repository ]; then
     rm -rf $PWD/repository
@@ -47,7 +53,9 @@ for file in $files
 do
     if [ ! -e $file ]; then
         warning "file $file does not exist"
+        rm -rf $BM_ARCHIVE_ROOT
         exit 10
     fi
 done
+rm -rf $BM_ARCHIVE_ROOT
 exit 0
